@@ -1136,6 +1136,7 @@ class FileSystemAttributes:
         "vpc": "vpc",
         "backup_id": "backupId",
         "kms_key": "kmsKey",
+        "removal_policy": "removalPolicy",
         "security_group": "securityGroup",
     },
 )
@@ -1147,6 +1148,7 @@ class FileSystemProps:
         vpc: aws_cdk.aws_ec2.IVpc,
         backup_id: typing.Optional[builtins.str] = None,
         kms_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
         security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
     ) -> None:
         '''(experimental) Properties for the FSx file system.
@@ -1155,6 +1157,7 @@ class FileSystemProps:
         :param vpc: (experimental) The VPC to launch the file system in.
         :param backup_id: (experimental) The ID of the backup. Specifies the backup to use if you're creating a file system from an existing backup. Default: - no backup will be used.
         :param kms_key: (experimental) The KMS key used for encryption to protect your data at rest. Default: - the aws/fsx default KMS key for the AWS account being deployed into.
+        :param removal_policy: (experimental) Policy to apply when the file system is removed from the stack. Default: RemovalPolicy.RETAIN
         :param security_group: (experimental) Security Group to assign to this file system. Default: - creates new security group which allows all outbound traffic.
 
         :see: https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-fsx-filesystem.html
@@ -1168,6 +1171,8 @@ class FileSystemProps:
             self._values["backup_id"] = backup_id
         if kms_key is not None:
             self._values["kms_key"] = kms_key
+        if removal_policy is not None:
+            self._values["removal_policy"] = removal_policy
         if security_group is not None:
             self._values["security_group"] = security_group
 
@@ -1219,6 +1224,17 @@ class FileSystemProps:
         result = self._values.get("kms_key")
         return typing.cast(typing.Optional[aws_cdk.aws_kms.IKey], result)
 
+    @builtins.property
+    def removal_policy(self) -> typing.Optional[aws_cdk.core.RemovalPolicy]:
+        '''(experimental) Policy to apply when the file system is removed from the stack.
+
+        :default: RemovalPolicy.RETAIN
+
+        :stability: experimental
+        '''
+        result = self._values.get("removal_policy")
+        return typing.cast(typing.Optional[aws_cdk.core.RemovalPolicy], result)
+
     @builtins.property
     def security_group(self) -> typing.Optional[aws_cdk.aws_ec2.ISecurityGroup]:
         '''(experimental) Security Group to assign to this file system.
@@ -1468,6 +1484,7 @@ class LustreDeploymentType(enum.Enum):
         "vpc": "vpc",
         "backup_id": "backupId",
         "kms_key": "kmsKey",
+        "removal_policy": "removalPolicy",
         "security_group": "securityGroup",
         "lustre_configuration": "lustreConfiguration",
         "vpc_subnet": "vpcSubnet",
@@ -1481,6 +1498,7 @@ class LustreFileSystemProps(FileSystemProps):
         vpc: aws_cdk.aws_ec2.IVpc,
         backup_id: typing.Optional[builtins.str] = None,
         kms_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
         security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
         lustre_configuration: LustreConfiguration,
         vpc_subnet: aws_cdk.aws_ec2.ISubnet,
@@ -1491,6 +1509,7 @@ class LustreFileSystemProps(FileSystemProps):
         :param vpc: (experimental) The VPC to launch the file system in.
         :param backup_id: (experimental) The ID of the backup. Specifies the backup to use if you're creating a file system from an existing backup. Default: - no backup will be used.
         :param kms_key: (experimental) The KMS key used for encryption to protect your data at rest. Default: - the aws/fsx default KMS key for the AWS account being deployed into.
+        :param removal_policy: (experimental) Policy to apply when the file system is removed from the stack. Default: RemovalPolicy.RETAIN
         :param security_group: (experimental) Security Group to assign to this file system. Default: - creates new security group which allows all outbound traffic.
         :param lustre_configuration: (experimental) Additional configuration for FSx specific to Lustre.
         :param vpc_subnet: (experimental) The subnet that the file system will be accessible from.
@@ -1509,6 +1528,8 @@ class LustreFileSystemProps(FileSystemProps):
             self._values["backup_id"] = backup_id
         if kms_key is not None:
             self._values["kms_key"] = kms_key
+        if removal_policy is not None:
+            self._values["removal_policy"] = removal_policy
         if security_group is not None:
             self._values["security_group"] = security_group
 
@@ -1560,6 +1581,17 @@ class LustreFileSystemProps(FileSystemProps):
         result = self._values.get("kms_key")
         return typing.cast(typing.Optional[aws_cdk.aws_kms.IKey], result)
 
+    @builtins.property
+    def removal_policy(self) -> typing.Optional[aws_cdk.core.RemovalPolicy]:
+        '''(experimental) Policy to apply when the file system is removed from the stack.
+
+        :default: RemovalPolicy.RETAIN
+
+        :stability: experimental
+        '''
+        result = self._values.get("removal_policy")
+        return typing.cast(typing.Optional[aws_cdk.core.RemovalPolicy], result)
+
     @builtins.property
     def security_group(self) -> typing.Optional[aws_cdk.aws_ec2.ISecurityGroup]:
         '''(experimental) Security Group to assign to this file system.
@@ -1880,6 +1912,7 @@ class LustreFileSystem(
         vpc: aws_cdk.aws_ec2.IVpc,
         backup_id: typing.Optional[builtins.str] = None,
         kms_key: typing.Optional[aws_cdk.aws_kms.IKey] = None,
+        removal_policy: typing.Optional[aws_cdk.core.RemovalPolicy] = None,
         security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
     ) -> None:
         '''
@@ -1891,6 +1924,7 @@ class LustreFileSystem(
         :param vpc: (experimental) The VPC to launch the file system in.
         :param backup_id: (experimental) The ID of the backup. Specifies the backup to use if you're creating a file system from an existing backup. Default: - no backup will be used.
         :param kms_key: (experimental) The KMS key used for encryption to protect your data at rest. Default: - the aws/fsx default KMS key for the AWS account being deployed into.
+        :param removal_policy: (experimental) Policy to apply when the file system is removed from the stack. Default: RemovalPolicy.RETAIN
         :param security_group: (experimental) Security Group to assign to this file system. Default: - creates new security group which allows all outbound traffic.
 
         :stability: experimental
@@ -1902,6 +1936,7 @@ class LustreFileSystem(
             vpc=vpc,
             backup_id=backup_id,
             kms_key=kms_key,
+            removal_policy=removal_policy,
             security_group=security_group,
         )
 
